@@ -13,6 +13,8 @@ from tesserocr import (
 
 from ocrd_utils import (
     getLogger, concat_padded,
+    make_file_id,
+    assert_file_grp_cardinality,
     rotate_image, transpose_image,
     membername,
     MIMETYPE_PAGE
@@ -39,14 +41,6 @@ class TesserocrDeskew(Processor):
         kwargs['ocrd_tool'] = OCRD_TOOL['tools'][TOOL]
         kwargs['version'] = OCRD_TOOL['version']
         super(TesserocrDeskew, self).__init__(*args, **kwargs)
-        if hasattr(self, 'output_file_grp'):
-            try:
-                self.page_grp, self.image_grp = self.output_file_grp.split(',')
-            except ValueError:
-                self.page_grp = self.output_file_grp
-                self.image_grp = FALLBACK_FILEGRP_IMG
-                LOG.info("No output file group for images specified, falling back to '%s'",
-                         FALLBACK_FILEGRP_IMG)
 
     def process(self):
         """Performs deskewing of the page / region with Tesseract on the workspace.
@@ -66,6 +60,8 @@ class TesserocrDeskew(Processor):
         
         Produce a new output file by serialising the resulting hierarchy.
         """
+        assert_file_grp_cardinality(self.input_file_grp, 1)
+        assert_file_grp_cardinality(self.output_file_grp, 1)
         oplevel = self.parameter['operation_level']
         
         with PyTessBaseAPI(
@@ -75,10 +71,11 @@ class TesserocrDeskew(Processor):
                 psm=PSM.AUTO_OSD
         ) as tessapi:
             for n, input_file in enumerate(self.input_files):
-                file_id = input_file.ID.replace(self.input_file_grp, self.image_grp)
+                file_id = make_file_id(input_file, self.output_file_grp)
                 page_id = input_file.pageId or input_file.ID
                 LOG.info("INPUT FILE %i / %s", n, page_id)
                 pcgts = page_from_file(self.workspace.download_file(input_file))
+                pcgts.set_pcGtsId(file_id)
                 page = pcgts.get_Page()
                 
                 # add metadata about this operation and its runtime parameters:
@@ -135,18 +132,12 @@ class TesserocrDeskew(Processor):
                                               "region '%s'" % region.id, input_file.pageId,
                                               file_id + '_' + region.id)
                 
-                # Use input_file's basename for the new file -
-                # this way the files retain the same basenames:
-                file_id = input_file.ID.replace(self.input_file_grp, self.page_grp)
-                if file_id == input_file.ID:
-                    file_id = concat_padded(self.page_grp, n)
                 self.workspace.add_file(
                     ID=file_id,
-                    file_grp=self.page_grp,
+                    file_grp=self.output_file_grp,
                     pageId=input_file.pageId,
                     mimetype=MIMETYPE_PAGE,
-                    local_filename=os.path.join(self.page_grp,
-                                                file_id + '.xml'),
+                    local_filename=os.path.join(self.output_file_grp, file_id + '.xml'),
                     content=to_xml(pcgts))
     
     def _process_segment(self, tessapi, segment, image, xywh, where, page_id, file_id):
