@@ -8,6 +8,8 @@ from tesserocr import PyTessBaseAPI, RIL, PSM
 from ocrd import Processor
 from ocrd_utils import (
     getLogger, concat_padded,
+    make_file_id,
+    assert_file_grp_cardinality,
     polygon_from_xywh,
     points_from_polygon,
     coordinates_for_segment,
@@ -49,6 +51,9 @@ class TesserocrSegmentLine(Processor):
         
         Produce a new output file by serialising the resulting hierarchy.
         """
+        assert_file_grp_cardinality(self.input_file_grp, 1)
+        assert_file_grp_cardinality(self.output_file_grp, 1)
+
         overwrite_lines = self.parameter['overwrite_lines']
         
         with PyTessBaseAPI(
@@ -130,11 +135,8 @@ class TesserocrSegmentLine(Processor):
                         region.add_TextLine(TextLineType(
                             id=line_id, Coords=CoordsType(line_points)))
                 
-                # Use input_file's basename for the new file -
-                # this way the files retain the same basenames:
-                file_id = input_file.ID.replace(self.input_file_grp, self.output_file_grp)
-                if file_id == input_file.ID:
-                    file_id = concat_padded(self.output_file_grp, n)
+                file_id = make_file_id(input_file, self.output_file_grp)
+                pcgts.set_pcGtsId(file_id)
                 self.workspace.add_file(
                     ID=file_id,
                     file_grp=self.output_file_grp,
